@@ -5,7 +5,7 @@ import tempfile
 import urllib.parse
 
 import mkdocs.utils
-from mkdocs.config import Config, config_options
+from mkdocs.config import Config
 from mkdocs.plugins import BasePlugin
 from mkdocs.structure.files import Files
 from mkdocs.structure.pages import Page
@@ -13,21 +13,22 @@ from mkdocs.structure.pages import Page
 try:
     from mkdocs.exceptions import PluginError
 except ImportError:
-    PluginError = SystemExit
+    PluginError = SystemExit  # type: ignore
 
-from . import editor
+from .config_items import ListOfFiles
+from .editor import FilesEditor
 
 log = logging.getLogger(f"mkdocs.plugins.{__name__}")
 log.addFilter(mkdocs.utils.warning_filter)
 
 
 class GenFilesPlugin(BasePlugin):
-    config_scheme = (("scripts", config_options.Type(list)),)
+    config_scheme = (("scripts", ListOfFiles(required=True)),)
 
     def on_files(self, files: Files, config: Config) -> Files:
         self._dir = tempfile.TemporaryDirectory(prefix="mkdocs_gen_files_")
 
-        with editor.FilesEditor(files, config, self._dir.name) as ed:
+        with FilesEditor(files, config, self._dir.name) as ed:
             for file_name in self.config["scripts"]:
                 try:
                     runpy.run_path(file_name)
@@ -42,7 +43,7 @@ class GenFilesPlugin(BasePlugin):
         repo_url = config.get("repo_url", None)
         edit_uri = config.get("edit_uri", None)
 
-        src_path = pathlib.Path(page.file.src_path)
+        src_path = pathlib.PurePath(page.file.src_path).as_posix()
         if src_path in self._edit_paths:
             path = self._edit_paths.pop(src_path)
             if repo_url and edit_uri:
